@@ -20,7 +20,7 @@ def iterExtract(query: str, choices: Iterable, scorer: Callable = fuzz.WRatio, p
                 score_cutoff=score_cutoff)
 
             if score >= score_cutoff:
-                yield (choice, score)
+                yield (match_choice, score, choice)
     else:
         for choice in choices:
             b = processor(choice) if processor else choice
@@ -132,10 +132,11 @@ def extractOne(query: str, choices: Iterable, scorer: Callable = fuzz.WRatio, pr
     """
     a = processor(query) if processor else query
 
-    match_found = False
+    result_score = 0
     result_choice = ""
 
     if hasattr(choices, "items"):
+        choice_key = ""
         for choice, match_choice in choices.items():
             b = processor(match_choice) if processor else match_choice
 
@@ -145,21 +146,29 @@ def extractOne(query: str, choices: Iterable, scorer: Callable = fuzz.WRatio, pr
                 score_cutoff=score_cutoff)
 
             if score >= score_cutoff:
-                score_cutoff = score
-                match_found = True
-                result_choice = choice
-    else:
-        for choice in choices:
-            b = processor(choice) if processor else choice
+                # very small increment for the score_cutoff, so when multiple
+                # elements have the same score the first one is used
+                score_cutoff = score + 0.00001
+                if score_cutoff > 100:
+                    return (match_choice, score, choice)
+                result_score = score
+                result_choice = match_choice
+                choice_key = choice
+        return (choice_key, result_score, result_choice) if result_score else None
+    
+    for choice in choices:
+        b = processor(choice) if processor else choice
 
-            score = scorer(
-                a, b,
-                processor=None,
-                score_cutoff=score_cutoff)
+        score = scorer(
+            a, b,
+            processor=None,
+            score_cutoff=score_cutoff)
 
-            if score >= score_cutoff:
-                score_cutoff = score
-                match_found = True
-                result_choice = choice
+        if score >= score_cutoff:
+            score_cutoff = score + 0.00001
+            if score_cutoff > 100:
+                return (choice, score)
+            result_score = score
+            result_choice = choice
 
-    return (result_choice, score_cutoff) if match_found else None
\ No newline at end of file
+    return (result_choice, result_score) if result_score else None
